@@ -67,6 +67,8 @@ class FastaProteins:
         which they were generated.
     shared_peptides : Set[str]
         A set of peptides that are shared by more than one protein group.
+    has_decoys : bool
+        Did the FASTA file have decoy proteins in it?
     """
 
     def __init__(
@@ -95,6 +97,7 @@ class FastaProteins:
         self._peptide_map = parsed[0]
         self._shared_peptides = parsed[1]
         self._protein_map = parsed[2]
+        self._has_decoys = parsed[3]
 
     @property
     def peptide_map(self):
@@ -108,6 +111,10 @@ class FastaProteins:
     def shared_peptides(self):
         return self._shared_peptides
 
+    @property
+    def has_decoys(self):
+        return self._has_decoys
+
 
 # Functions -------------------------------------------------------------------
 def make_decoys(
@@ -266,26 +273,21 @@ def read_fasta(
     # Build the decoy map:
     decoy_map = {}
     no_decoys = 0
+    has_decoys = False
     for prot_name in proteins:
         if not prot_name.startswith(decoy_prefix):
             decoy = decoy_prefix + prot_name
+            decoy_map[prot_name] = decoy
             if decoy in proteins.keys():
-                decoy_map[prot_name] = decoy
+                has_decoys = True
             else:
                 no_decoys += 1
 
-    if no_decoys:
+    if no_decoys and no_decoys < len(decoy_map):
         LOGGER.warning(
             "Found %i target proteins without matching decoys.", no_decoys
         )
 
-    if not decoy_map:
-        raise ValueError(
-            "No decoy proteins could be mapped to target proteins. Verify that"
-            " 'decoy_prefix' is correct and that decoy proteins are present "
-            "in your database."
-        )
-
     LOGGER.info("Building protein groups...")
     # Group Proteins
     num_before_group = len(proteins)
@@ -296,6 +298,13 @@ def read_fasta(
         len(proteins),
     )
 
+    if not has_decoys:
+        LOGGER.info("No decoy sequences were found in the FASTA file.")
+        LOGGER.info(
+            "\t - Creating decoy protein groups that mirror the target "
+            "proteins."
+        )
+
     # unique peptides:
     LOGGER.info("Discarding shared peptides...")
     shared_peptides = set()
@@ -320,7 +329,7 @@ def read_fasta(
         total_proteins,
     )
 
-    return unique_peptides, shared_peptides, decoy_map
+    return unique_peptides, shared_peptides, decoy_map, has_decoys
 
 
 def digest(
